#!/opt/omni/bin/ruby

require 'json'
require 'pp'
require 'open-uri'

json = <<-EOJ
{
  "number": 1.23,
  "bignum_as_string": "281474976710656",
  "test": "a text string",
  "container": { "key1": 1234 },
  "array": [  1234, 
              "string",
              { "crazy": "like a fox" }
           ]
}
EOJ

expected = {
  'array`0'   => 1234,
  'array`1'   => "string",
  'array`2`crazy'    => "like a fox",
  'bignum_as_string' => "281474976710656",
  'container`key1'   => 1234,
  'number'          => 1.23,
  'services'        => 7,
  'test'            => "a text string",
}

def terrifying_flatten(inbound, prefix = nil)
  outbound = {}
  if inbound.kind_of? (Hash) then
    inbound.each do |key, val|
      if val.kind_of?(Hash) || val.kind_of?(Array)    
        outbound.merge!(terrifying_flatten(val, (prefix ? prefix + '`' : '') + key.to_s))      
      else
        outbound[(prefix ? prefix + '`' : '') + key.to_s] = val
      end
    end
  else
    inbound.each_with_index do |val, key|
      if val.kind_of?(Hash) || val.kind_of?(Array)    
        outbound.merge!(terrifying_flatten(val, (prefix ? prefix + '`' : '') + key.to_s))      
      else
        outbound[(prefix ? prefix + '`' : '') + key.to_s] = val
      end
    end    
  end
  outbound
end

def window_dressing(inbound)
  inbound['services'] = inbound.keys.length
  outbound = {}
  inbound.keys.sort.each { |k| outbound[k] = inbound[k] }
  outbound
end

saw = window_dressing(terrifying_flatten(JSON.parse(json)))

#pp "Expected:"
#pp expected

#pp "----------------------"
#pp "Saw:"
#pp saw

#pp "----------------------"
#pp "Equal?:"
#pp expected == saw

url = 'http://ams1-1.f.fontdeck.com/_stats'
content = open(url).read
data = ::JSON.parse(content)

pp data

saw = window_dressing(terrifying_flatten(data))

scan = {}

saw.each do |metric_name, value|
  scan[metric_name] = {
    :label => metric_name, # No way of knowing a prettier name
    :type => value =~ /^\d+(\.\d+)?$/ ? :numeric : :text,
  }
end

pp scan



